# -*- coding: utf-8 -*-
"""
This class is aim to install lamp server(Linux, Apache, Mysql and PHP) into your
local environment.

Usage:
    $ sudo pip install ezhost
    $ python3 ezhost lamp

Author: Zhe Xiao

Date: 05/20/2016

Contact: zhexiao27@gmail.com
    
Github: https://github.com/zhexiao/ezhost.git
"""

from ServerAbstract import *
import os

class ServerLamp(ServerAbstract):
    def install(self):
        command = 'fab -f /var/www/html/ezhost/ezhost/ServerLamp local setup'
        os.system(command)


def setup():
    """ deploy function """
    if env.environment not in ["local"]:
        print( red(' * please choose a environment.') )
    else:
        # exec the specify environment install function 
        globals()['setup_{0}'.format(env.environment)]()  
        

def local():
    """ choose local environment """
    env.hosts = ['127.0.0.1:2222']
    env.user = 'vagrant'
    env.password = 'vagrant'
    env.environment = 'local'

def setup_local():
    update_sys()
    install_apache()

def update_sys():
    """update system package"""
    sudo('apt-get update -y')
    print(green(' * successfully updated your system package'))

def install_apache():
    """ setup libraries """
    if prompt(red(' * Install apache2 (y/n)?'), default='y') == 'y':
        sudo('apt-get install apache2 -y')
        print(green(' * successfully installed apache2'))




"""
This module contains `main` method plus related subroutines.
`main` is executed as the command line ``ezhost`` program and takes care of
parsing options and commands

The other callables defined in this module are internal only. Anything useful
to individuals leveraging Fabric as a library, should be kept elsewhere.
"""

def main():
    command = 'sudo touch /usr/local/bin/ezhost'
    os.system(command)


#!/usr/bin/python
import sys

from ServerLists import ServerLists
from ServerLamp import ServerLamp

"""
Check args
"""
try:
    arg1 = sys.argv[0]
    arg2 = sys.argv[1]
    server = ServerLists(arg2)
except Exception as e:
    raise e

"""
Call server install function
"""
eval(server.name)().install()






# -*- coding: utf-8 -*-
"""
Abstract class for all server class
"""

# internal libs
from abc import ABCMeta, abstractmethod
import os

# fabric libs
from fabric.colors import red, green
from fabric.api import env, prompt, run, sudo, local, put
from fabric.contrib.files import exists
from fabric.state import output

# hide exec command
output['running'] = False

class ServerAbstract(metaclass=ABCMeta):
    @abstractmethod
    def install(self):
        pass
        

